@@ -4,18 +4,16 @@ this module houses all the code to just convert a directory of random dicom file
 
 @author: abrys
 """
-import dicom2nifti.compressed_dicom as compressed_dicom
-
 import gc
+import logging
 import os
 import re
 import traceback
 import unicodedata
 
+import pydicom
 from pydicom.tag import Tag
 
-import logging
-
 import dicom2nifti.common as common
 import dicom2nifti.convert_dicom as convert_dicom
 import dicom2nifti.settings
@@ -39,14 +37,14 @@ def convert_directory(dicom_directory, output_folder, compression=True, reorient
             file_path = os.path.join(root, dicom_file)
             # noinspection PyBroadException
             try:
-                if compressed_dicom.is_dicom_file(file_path):
+                if common.is_dicom_file(file_path):
                     # read the dicom as fast as possible
                     # (max length for SeriesInstanceUID is 64 so defer_size 100 should be ok)
 
-                    dicom_headers = compressed_dicom.read_file(file_path,
-                                                               defer_size="1 KB",
-                                                               stop_before_pixels=False,
-                                                               force=dicom2nifti.settings.pydicom_read_force)
+                    dicom_headers = pydicom.read_file(file_path,
+                                                      defer_size="1 KB",
+                                                      stop_before_pixels=False,
+                                                      force=dicom2nifti.settings.pydicom_read_force)
                     if not _is_valid_imaging_dicom(dicom_headers):
                         logger.info("Skipping: %s" % file_path)
                         continue
